from ._account_tax import AccountTaxModel
from ._country import CountryModel
from ._crm_tag import CRMTagModel
from ._integration import OdooIntegration
from ._partner_category import PartnerCategoryModel
from ._partner import PartnerModel
from ._product_category import ProductCategoryModel
from ._product_template import ProductTemplateModel
from ._product import ProductModel
from ._stock import StockModel
from ._sale_order import SaleOrderModel
from ._user import UserModel
from ._analytic_account import AnalyticAccountModel
from ._payment_term import PaymentTermModel
from ._company import CompanyModel
from ._purchase_order import PurchaseOrderModel
from ._account_move import AccountMoveModel